@@ -108,6 +108,9 @@
 #include "agent_module_includes.h"
 #include "mib_module_includes.h"
 
+char            dontReadConfigFiles;
+char           *optconfigfile;
+
 #ifdef HAVE_UNISTD_H
 void
 snmpd_set_agent_user(const char *token, char *cptr)
@@ -183,9 +186,9 @@ snmpd_set_agent_address(const char *token, char *cptr)
         /*
          * append to the older specification string 
          */
-        snprintf(buf, SPRINT_MAX_LEN, "%s,%s", ptr, cptr);
+        sprintf(buf, "%s,%s", ptr, cptr);
     } else {
-        strncpy(buf, cptr, SPRINT_MAX_LEN);
+        strcpy(buf, cptr);
     }
 
     DEBUGMSGTL(("snmpd_ports", "port spec: %s\n", buf));
@@ -240,6 +243,9 @@ init_agent_read_config(const char *app)
                                 snmpd_free_trapcommunity,
                                 "community-string");
 #endif /* support for community based SNMP */
+    netsnmp_ds_register_config(ASN_OCTET_STR, app, "v1trapaddress", 
+                               NETSNMP_DS_APPLICATION_ID, 
+                               NETSNMP_DS_AGENT_TRAP_ADDR);
 #ifdef HAVE_UNISTD_H
     register_app_config_handler("agentuser",
                                 snmpd_set_agent_user, NULL, "userid");
@@ -279,9 +285,6 @@ update_config(void)
     snmp_call_callbacks(SNMP_CALLBACK_APPLICATION,
                         SNMPD_CALLBACK_PRE_UPDATE_CONFIG, NULL);
     free_config();
-#ifdef USING_MIBII_VACM_CONF_MODULE
-    vacm_standard_views(0,0,NULL,NULL);
-#endif
     read_configs();
 }
 
