@@ -150,19 +150,29 @@ int             current_proc_entry;
 #define	HRSWRUNPERF_MEM		10
 
 struct variable4 hrswrun_variables[] = {
-    {HRSWRUN_OSINDEX, ASN_INTEGER, RONLY, var_hrswrun, 1, {1}},
-    {HRSWRUN_INDEX, ASN_INTEGER, RONLY, var_hrswrun, 3, {2, 1, 1}},
-    {HRSWRUN_NAME, ASN_OCTET_STR, RONLY, var_hrswrun, 3, {2, 1, 2}},
-    {HRSWRUN_ID, ASN_OBJECT_ID, RONLY, var_hrswrun, 3, {2, 1, 3}},
-    {HRSWRUN_PATH, ASN_OCTET_STR, RONLY, var_hrswrun, 3, {2, 1, 4}},
-    {HRSWRUN_PARAMS, ASN_OCTET_STR, RONLY, var_hrswrun, 3, {2, 1, 5}},
-    {HRSWRUN_TYPE, ASN_INTEGER, RONLY, var_hrswrun, 3, {2, 1, 6}},
-    {HRSWRUN_STATUS, ASN_INTEGER, RONLY, var_hrswrun, 3, {2, 1, 7}}
+    {HRSWRUN_OSINDEX, ASN_INTEGER, NETSNMP_OLDAPI_RONLY,
+     var_hrswrun, 1, {1}},
+    {HRSWRUN_INDEX, ASN_INTEGER, NETSNMP_OLDAPI_RONLY,
+     var_hrswrun, 3, {2, 1, 1}},
+    {HRSWRUN_NAME, ASN_OCTET_STR, NETSNMP_OLDAPI_RONLY,
+     var_hrswrun, 3, {2, 1, 2}},
+    {HRSWRUN_ID, ASN_OBJECT_ID, NETSNMP_OLDAPI_RONLY,
+     var_hrswrun, 3, {2, 1, 3}},
+    {HRSWRUN_PATH, ASN_OCTET_STR, NETSNMP_OLDAPI_RONLY,
+     var_hrswrun, 3, {2, 1, 4}},
+    {HRSWRUN_PARAMS, ASN_OCTET_STR, NETSNMP_OLDAPI_RONLY,
+     var_hrswrun, 3, {2, 1, 5}},
+    {HRSWRUN_TYPE, ASN_INTEGER, NETSNMP_OLDAPI_RONLY,
+     var_hrswrun, 3, {2, 1, 6}},
+    {HRSWRUN_STATUS, ASN_INTEGER, NETSNMP_OLDAPI_RONLY,
+     var_hrswrun, 3, {2, 1, 7}}
 };
 
 struct variable4 hrswrunperf_variables[] = {
-    {HRSWRUNPERF_CPU, ASN_INTEGER, RONLY, var_hrswrun, 3, {1, 1, 1}},
-    {HRSWRUNPERF_MEM, ASN_INTEGER, RONLY, var_hrswrun, 3, {1, 1, 2}}
+    {HRSWRUNPERF_CPU, ASN_INTEGER, NETSNMP_OLDAPI_RONLY,
+     var_hrswrun, 3, {1, 1, 1}},
+    {HRSWRUNPERF_MEM, ASN_INTEGER, NETSNMP_OLDAPI_RONLY,
+     var_hrswrun, 3, {1, 1, 2}}
 };
 
 oid             hrswrun_variables_oid[] = { 1, 3, 6, 1, 2, 1, 25, 4 };
@@ -326,7 +336,7 @@ init_hr_swrun(void)
     auto_nlist(NPROC_SYMBOL, 0, 0);
 #endif
 
-    proc_table = 0;
+    proc_table = NULL;
 
     REGISTER_MIB("host/hr_swrun", hrswrun_variables, variable4,
                  hrswrun_variables_oid);
@@ -369,7 +379,7 @@ header_hrswrun(struct variable *vp,
            (vp->namelen + 1) * sizeof(oid));
     *length = vp->namelen + 1;
 
-    *write_method = 0;
+    *write_method = (WriteMethod*)0;
     *var_len = sizeof(long);    /* default to 'long' results */
     return (MATCH_SUCCEEDED);
 }
@@ -453,7 +463,7 @@ header_hrswrunEntry(struct variable *vp,
     memcpy((char *) name, (char *) newname,
            (vp->namelen + 1) * sizeof(oid));
     *length = vp->namelen + 1;
-    *write_method = 0;
+    *write_method = (WriteMethod*)0;
     *var_len = sizeof(long);    /* default to 'long' results */
 
     DEBUGMSGTL(("host/hr_swrun", "... get process stats "));
@@ -468,82 +478,6 @@ header_hrswrunEntry(struct variable *vp,
 	 *
 	 *********************/
 
-#if defined(linux)
-static char     *
-skip_to_next_field(char *cp)
-{
-    while (*cp && ! isspace(*cp)) /* skip past non-space */
-	++cp;
-    while (*cp && isspace(*cp)) /* skip past space */
-	++cp;
-    return cp;
-
-}
-
-static char     *
-get_proc_file_line(char *fmt,
-		    int pid,
-		    char *buf,
-		    int buflen )
-{
-    static char     string[1024];
-    FILE *fp;
-    *buf = '\0';
-    sprintf(string,fmt,pid);
-    if (   ((fp = fopen(string, "r")) == NULL)
-	|| (fgets(buf, buflen, fp) == NULL) ) {
-	if (fp)
-	    fclose(fp);
-	return NULL;
-    }
-    fclose(fp);
-    return buf;
-}
-
-static char     *
-get_proc_stat_field(int pid,
-		    char *buf,
-		    int buflen,
-		    int skip )
-{
-    int i;
-    char *cp;
-
-    if ((cp = get_proc_file_line("/proc/%d/stat", pid, buf, buflen)) == NULL )
-	return NULL;
-    for (i = 0; *cp && i < skip; ++i) {
-	cp = skip_to_next_field(cp);
-    }
-    return cp;
-}
-
-static char *
-get_proc_name_from_cmdline(int pid,
-			    char *buf,
-			    int buflen )
-{
-    return get_proc_file_line("/proc/%d/cmdline", pid, buf, buflen);
-}
-
-static char *
-get_proc_name_from_status(int pid,
-	    char *buf,
-	    int buflen )
-{
-    char *cp,*cp2;
-    if ((cp = get_proc_file_line("/proc/%d/status", pid, buf, buflen)) == NULL )
-	return NULL;
-    cp = strchr(cp, ':');
-    if ( cp == NULL ) {
-	return NULL;    /* the process file is malformed */
-    }
-    cp = skip_to_next_field(cp);
-    cp2 = strchr(cp, '\n');
-    if (cp2)
-	*cp2 = 0;
-    return cp;
-}
-#endif
 
 u_char         *
 var_hrswrun(struct variable * vp,
@@ -680,18 +614,25 @@ var_hrswrun(struct variable * vp,
 #elif HAVE_KVM_GETPROCS
     #if defined(freebsd5) && __FreeBSD_version >= 500014
         strcpy(string, proc_table[LowProcIndex].ki_comm);
-    #elif defined(dragonfly) && __DragonFly_version >= 190000
-        strcpy(string, proc_table[LowProcIndex].kp_comm);
     #else
         strcpy(string, proc_table[LowProcIndex].kp_proc.p_comm);
     #endif
 #elif defined(linux)
-	if( (cp=get_proc_name_from_status(pid,buf,sizeof(buf))) == NULL ) {
+        sprintf(string, "/proc/%d/status", pid);
+        if ((fp = fopen(string, "r")) == NULL) {
             strcpy(string, "<exited>");
             *var_len = strlen(string);
             return (u_char *) string;
         }
+        fgets(buf, sizeof(buf), fp);    /* Name: process name */
+        cp = buf;
+        while (*cp != ':')
+            ++cp;
+        ++cp;
+        while (isspace(*cp))
+            ++cp;
         strcpy(string, cp);
+        fclose(fp);
 #elif defined(cygwin)
         /* if (lowproc.process_state & (PID_ZOMBIE | PID_EXITED)) */
         if (lowproc.process_state & PID_EXITED || (lowproc.exitcode & ~0xffff))
@@ -796,26 +737,44 @@ var_hrswrun(struct variable * vp,
 #elif HAVE_KVM_GETPROCS
     #if defined(freebsd5) && __FreeBSD_version >= 500014
         strcpy(string, proc_table[LowProcIndex].ki_comm);
-    #elif defined(dragonfly) && __DragonFly_version >= 190000
-        strcpy(string, proc_table[LowProcIndex].kp_comm);
     #else
         strcpy(string, proc_table[LowProcIndex].kp_proc.p_comm);
     #endif
 #elif defined(linux)
-        cp = get_proc_name_from_cmdline(pid,buf,sizeof(buf)-1);
-        if (cp != NULL && *cp)    /* argv[0] '\0' argv[1] '\0' .... */
-            strcpy(string, cp);
+        sprintf(string, "/proc/%d/cmdline", pid);
+        if ((fp = fopen(string, "r")) == NULL) {
+            strcpy(string, "<exited>");
+            *var_len = strlen(string);
+            return (u_char *) string;
+        }
+        if (fgets(buf, sizeof(buf) - 1, fp))    /* argv[0] '\0' argv[1] '\0' .... */
+            strcpy(string, buf);
         else {
             /*
              * swapped out - no cmdline 
              */
-	    if( (cp=get_proc_name_from_status(pid,buf,sizeof(buf)-1)) == NULL ) {
-		strcpy(string, "<exited>");
-		*var_len = strlen(string);
-		return (u_char *) string;
-	    }
+            fclose(fp);
+            sprintf(string, "/proc/%d/status", pid);
+            if ((fp = fopen(string, "r")) == NULL)
+                return NULL;
+            if (!fgets(buf, sizeof(buf), fp)) {
+                fclose(fp);
+                return NULL;    /* the process probably died */
+            }
+            cp = strchr(buf, ':');
+            if ( cp == NULL ) {
+                fclose(fp);
+                return NULL;    /* the process file is malformed */
+            }
+            ++cp;
+            while (isspace(*cp))
+                ++cp;
             strcpy(string, cp);
+            cp = strchr(string, '\n');
+            if (cp)
+                *cp = 0;
         }
+        fclose(fp);
 #elif defined(cygwin)
         /* if (lowproc.process_state & (PID_ZOMBIE | PID_EXITED)) */
         if (lowproc.process_state & PID_EXITED || (lowproc.exitcode & ~0xffff))
@@ -904,12 +863,26 @@ var_hrswrun(struct variable * vp,
             argv++;
         }
 #elif defined(linux)
-        memset(buf, 0, sizeof(buf));
-        if( (cp=get_proc_name_from_cmdline(pid,buf,sizeof(buf)-2)) == NULL ) {
+        sprintf(string, "/proc/%d/cmdline", pid);
+        if ((fp = fopen(string, "r")) == NULL) {
             strcpy(string, "");
             *var_len = 0;
             return (u_char *) string;
         }
+        memset(buf, 0, sizeof(buf));
+
+        /*
+         * argv[0] '\0' argv[1] '\0' .... 
+         */
+        if (!fgets(buf, sizeof(buf) - 2, fp)) {
+            /*
+             * maybe be empty (even argv[0] is missing) 
+             */
+            string[0] = '\0';
+            *var_len = 0;
+            fclose(fp);
+            return (u_char *)string;
+        }
 
         /*
          * Skip over argv[0] 
@@ -934,6 +907,7 @@ var_hrswrun(struct variable * vp,
             ++cp;
         ++cp;
         strcpy(string, cp);
+        fclose(fp);
 #elif defined(cygwin)
         string[0] = 0;
 #else
@@ -969,11 +943,7 @@ var_hrswrun(struct variable * vp,
 	} else
 	    long_return = 4;	/* application */
     #else
-      #if defined(dragonfly) && __DragonFly_version >= 190000
-        if (proc_table[LowProcIndex].kp_flags & P_SYSTEM)
-      #else
         if (proc_table[LowProcIndex].kp_proc.p_flag & P_SYSTEM)
-      #endif
 	    long_return = 2;	/* operatingSystem */
 	else
 	    long_return = 4;	/* application */
@@ -1014,8 +984,6 @@ var_hrswrun(struct variable * vp,
 #if HAVE_KVM_GETPROCS
     #if defined(freebsd5) && __FreeBSD_version >= 500014
         switch (proc_table[LowProcIndex].ki_stat) {
-    #elif defined(dragonfly) && __DragonFly_version >= 190000
-        switch (proc_table[LowProcIndex].kp_stat) {
     #else
         switch (proc_table[LowProcIndex].kp_proc.p_stat) {
     #endif
@@ -1066,7 +1034,16 @@ var_hrswrun(struct variable * vp,
         }
 #endif
 #else
-	if ((cp = get_proc_stat_field(pid,buf,sizeof(buf),2)) != NULL ) {
+        sprintf(string, "/proc/%d/stat", pid);
+        if ((fp = fopen(string, "r")) != NULL) {
+            fgets(buf, sizeof(buf), fp);
+            cp = buf;
+            for (i = 0; i < 2; ++i) {   /* skip two fields */
+                while (*cp != ' ')
+                    ++cp;
+                ++cp;
+            }
+
             switch (*cp) {
             case 'R':
                 long_return = 1;        /* running */
@@ -1083,6 +1060,7 @@ var_hrswrun(struct variable * vp,
                 long_return = 4;        /* invalid */
                 break;
             }
+            fclose(fp);
         } else
             long_return = 4;    /* invalid */
 #endif
@@ -1113,30 +1091,32 @@ var_hrswrun(struct variable * vp,
         long_return = 0;
     #elif defined(freebsd5)
         long_return = proc_table[LowProcIndex].ki_runtime / 100000;
-    #elif defined(dragonfly) && __DragonFly_version >= 190000
-        long_return = proc_table[LowProcIndex].kp_lwp.kl_uticks +
-            proc_table[LowProcIndex].kp_lwp.kl_sticks +
-            proc_table[LowProcIndex].kp_lwp.kl_iticks;
-    #elif defined(dragonfly)
-        long_return = proc_table[LowProcIndex].kp_eproc.e_uticks +
-            proc_table[LowProcIndex].kp_eproc.e_sticks +
-            proc_table[LowProcIndex].kp_eproc.e_iticks;
     #else
         long_return = proc_table[LowProcIndex].kp_proc.p_uticks +
             proc_table[LowProcIndex].kp_proc.p_sticks +
             proc_table[LowProcIndex].kp_proc.p_iticks;
     #endif
 #elif defined(linux)
-	if ((cp = get_proc_stat_field(pid,buf,sizeof(buf),13)) == NULL ) {
+        sprintf(string, "/proc/%d/stat", pid);
+        if ((fp = fopen(string, "r")) == NULL) {
             long_return = 0;
             return (u_char *) & long_return;
         }
+        fgets(buf, sizeof(buf), fp);
+        cp = buf;
+        for (i = 0; i < 13; ++i) {      /* skip 13 fields */
+            while (*cp != ' ')
+                ++cp;
+            ++cp;
+        }
 
         long_return = atoi(cp); /* utime */
 
-        cp = skip_to_next_field(cp);
-
+        while (*cp != ' ')
+            ++cp;
+        ++cp;
         long_return += atoi(cp);        /* + stime */
+        fclose(fp);
 #elif defined(sunos4)
         long_return = proc_table[LowProcIndex].p_time;
 #elif defined(cygwin)
@@ -1228,8 +1208,6 @@ var_hrswrun(struct variable * vp,
         long_return =
     #if defined(freebsd5)
             proc_table[LowProcIndex].ki_size / 1024;
-    #elif defined(dragonfly) && __DragonFly_version >= 190000
-            proc_table[LowProcIndex].kp_vm_map.size / 1024;
     #else
             proc_table[LowProcIndex].kp_eproc.e_vm.vm_map.size / 1024;
     #endif
@@ -1240,11 +1218,20 @@ var_hrswrun(struct variable * vp,
         long_return = long_return * (getpagesize() / 1024);
   #endif
 #elif defined(linux)
-	if ((cp = get_proc_stat_field(pid,buf,sizeof(buf),23)) == NULL ) {
+        sprintf(string, "/proc/%d/stat", pid);
+        if ((fp = fopen(string, "r")) == NULL) {
             long_return = 0;
             return (u_char *) & long_return;
         }
+        fgets(buf, sizeof(buf), fp);
+        cp = buf;
+        for (i = 0; i < 23; ++i) {      /* skip 23 fields */
+            while (*cp != ' ')
+                ++cp;
+            ++cp;
+        }
         long_return = atoi(cp) * (getpagesize() / 1024);        /* rss */
+        fclose(fp);
 #elif defined(cygwin)
         {
             DWORD           n = lowproc.dwProcessId;
@@ -1541,9 +1528,6 @@ Get_Next_HR_SWRun(void)
     #if defined(freebsd5) && __FreeBSD_version >= 500014
         if (proc_table[current_proc_entry].ki_stat != 0)
             return proc_table[current_proc_entry++].ki_pid;
-    #elif defined(dragonfly) && __DragonFly_version >= 190000
-        if (proc_table[current_proc_entry].kp_stat != 0)
-            return proc_table[current_proc_entry++].kp_pid;
     #else
         if (proc_table[current_proc_entry].kp_proc.p_stat != 0)
             return proc_table[current_proc_entry++].kp_proc.p_pid;
