@@ -17,15 +17,15 @@
 #include <net-snmp/agent/snmp_vars.h>
 #include <net-snmp/agent/var_struct.h>
 
-#if defined(IFNET_NEEDS_KERNEL) && !defined(_KERNEL)
+#if defined(NETSNMP_IFNET_NEEDS_KERNEL) && !defined(_KERNEL)
 #define _KERNEL 1
 #define _I_DEFINED_KERNEL
 #endif
-#ifndef WIN32
+#if defined (WIN32) && !defined (cygwin)
+#include <winsock.h>
+#else /* WIN32 */
 #include <sys/socket.h>
 #include <net/if.h>
-#else
-#include <winsock.h>
 #endif /* WIN32 */
 #ifdef _I_DEFINED_KERNEL
 #undef _KERNEL
