@@ -1,6 +1,17 @@
+#ifdef __cplusplus
+extern          "C" {
+#endif
+
 /*
- * internal header, not for distribution
+ * struct for netlink extras
  */
+struct address_flag_info {
+    int bcastflg;
+    int anycastflg;
+    struct in_addr *inp;
+};
+ 
+#define IS_APIPA(a)  (((in_addr_t)(a << 16)) == 0xFEA90000)
 
 int
 _netsnmp_ioctl_ipaddress_container_load_v4(netsnmp_container *container,
@@ -10,6 +21,11 @@ _netsnmp_ioctl_ipaddress_set_v4(netsnmp_ipaddress_entry * entry);
 int
 _netsnmp_ioctl_ipaddress_remove_v4(netsnmp_ipaddress_entry * entry);
 
+int
+netsnmp_access_ipaddress_ioctl_get_interface_count(int sd, struct ifconf * ifc);
+
+struct address_flag_info
+netsnmp_access_other_info_get(int index, int family);
 
 /*
  * struct ioctl for arch_data
@@ -34,3 +50,8 @@ netsnmp_ioctl_ipaddress_extras_get(netsnmp_ipaddress_entry *entry);
 
 int
 _netsnmp_ioctl_ipaddress_delete_v4(netsnmp_ipaddress_entry * entry);
+
+#ifdef __cplusplus
+}
+#endif
+
