@@ -16,7 +16,7 @@
 
 #include <net-snmp/net-snmp-config.h>
 
-#if defined(IFNET_NEEDS_KERNEL) && !defined(_KERNEL)
+#if defined(NETSNMP_IFNET_NEEDS_KERNEL) && !defined(_KERNEL)
 #define _KERNEL 1
 #define _I_DEFINED_KERNEL
 #endif
@@ -118,7 +118,6 @@
 
 #include "ip.h"
 #include "interfaces.h"
-#include "sysORTable.h"
 
 #ifdef cygwin
 #include <windows.h>
@@ -221,7 +220,7 @@ var_ipAddrEntry(struct variable *vp,
 #if !defined(freebsd2) && !defined(hpux11) && !defined(linux)
         if (Interface_Scan_Next(&interface, NULL, &ifnet, &in_ifaddr) == 0)
             break;
-#ifdef STRUCT_IFNET_HAS_IF_ADDRLIST
+#ifdef HAVE_STRUCT_IFNET_IF_ADDRLIST
         if (ifnet.if_addrlist == 0)
             continue;           /* No address found for interface */
 #endif
@@ -290,7 +289,7 @@ var_ipAddrEntry(struct variable *vp,
         return (NULL);
     memcpy((char *) name, (char *) lowest, 14 * sizeof(oid));
     *length = 14;
-    *write_method = 0;
+    *write_method = (WriteMethod*)0;
     *var_len = sizeof(long_return);
     switch (vp->magic) {
     case IPADADDR:
@@ -982,7 +981,6 @@ var_ipAddrEntry(struct variable *vp,
     DWORD           status = NO_ERROR;
     DWORD           statusRetry = NO_ERROR;
     DWORD           dwActualSize = 0;
-    void           *result = NULL;
     static in_addr_t 	addr_ret;
     
     /*
@@ -1019,6 +1017,7 @@ var_ipAddrEntry(struct variable *vp,
                 }
             } else {
                 if (snmp_oid_compare(current, 14, name, *length) > 0) {
+
                     lowinterface = i;
                     memcpy(lowest, current, 14 * sizeof(oid));
                     break;      /* Since the table is sorted, no need to search further  */
@@ -1027,52 +1026,46 @@ var_ipAddrEntry(struct variable *vp,
         }
     }
 
-    if (lowinterface < 0)
-        goto out;
-
+    if (lowinterface < 0) {
+        free(pIpAddrTable);
+        return NULL;
+    }
     i = lowinterface;
     memcpy(name, lowest, 14 * sizeof(oid));
     *length = 14;
     *write_method = 0;
+    *var_len = sizeof(long_return);
     switch (vp->magic) {
     case IPADADDR:
-        *var_len = sizeof(addr_ret);
-        addr_ret = pIpAddrTable->table[i].dwAddr;
-        result = &addr_ret;
-        break;
+    	 *var_len = sizeof(addr_ret);
+    	 addr_ret = pIpAddrTable->table[i].dwAddr;
+        return (u_char *) & addr_ret;
 
     case IPADIFINDEX:
-        *var_len = sizeof(long_return);
         long_return = pIpAddrTable->table[i].dwIndex;
-        result = &long_return;
-        break;
+        free(pIpAddrTable);
+        return (u_char *) & long_return;
 
     case IPADNETMASK:
-        *var_len = sizeof(addr_ret);
+    	 *var_len = sizeof(addr_ret);
         addr_ret = pIpAddrTable->table[i].dwMask;
-        result = &addr_ret;
-        break;
+        free(pIpAddrTable);
+        return (u_char *) & addr_ret;
 
     case IPADBCASTADDR:
-        *var_len = sizeof(long_return);
         long_return = pIpAddrTable->table[i].dwBCastAddr;
-        result = &long_return;
-        break;
+        free(pIpAddrTable);
+        return (u_char *) & long_return;
 
     case IPADREASMMAX:
-        *var_len = sizeof(long_return);
         long_return = pIpAddrTable->table[i].dwReasmSize;
-        result = &long_return;
-        break;
+        free(pIpAddrTable);
+        return (u_char *) & long_return;
 
     default:
         DEBUGMSGTL(("snmpd", "unknown sub-id %d in var_ipAddrEntry\n",
                     vp->magic));
-        break;
     }
-
-out:
-    free(pIpAddrTable);
-    return result;
+    return NULL;
 }
 #endif                          /* WIN32 cygwin */
