@@ -49,11 +49,11 @@
 #include <net-snmp/net-snmp-includes.h>
 #include <net-snmp/agent/net-snmp-agent-includes.h>
 #include <net-snmp/agent/auto_nlist.h>
+#include <net-snmp/agent/sysORTable.h>
 
-#include "util_funcs.h"
+#include "util_funcs/MIB_STATS_CACHE_TIMEOUT.h"
 #include "tcp.h"
 #include "tcpTable.h"
-#include "sysORTable.h"
 
 #ifndef MIB_STATS_CACHE_TIMEOUT
 #define MIB_STATS_CACHE_TIMEOUT	5
@@ -167,12 +167,6 @@ init_tcp(void)
 #define USES_SNMP_DESIGNED_TCPSTAT
 #endif
 
-#ifdef NETBSD_STATS_VIA_SYSCTL
-#define TCP_STAT_STRUCTURE      struct tcp_mib
-#define USES_SNMP_DESIGNED_TCPSTAT
-#undef TCP_NSTATS
-#endif
-
 #if defined (WIN32) || defined (cygwin)
 #include <iphlpapi.h>
 #define TCP_STAT_STRUCTURE     MIB_TCPSTATS
@@ -183,11 +177,6 @@ init_tcp(void)
 #define USES_TRADITIONAL_TCPSTAT
 #endif
 
-#ifdef dragonfly
-#define TCP_STAT_STRUCTURE	struct tcp_stats
-#define USES_TRADITIONAL_TCPSTAT
-#endif
-
 #if !defined(TCP_STAT_STRUCTURE)
 #define TCP_STAT_STRUCTURE	struct tcpstat
 #define USES_TRADITIONAL_TCPSTAT
@@ -224,6 +213,11 @@ tcp_handler(netsnmp_mib_handler          *handler,
      */
 #if defined(_USE_FIRST_PROTOCOL)
     tcp_load(NULL, NULL);
+#elif !defined(hpux11)
+    if (!netsnmp_cache_is_valid(reqinfo, reginfo->handlerName)) {
+        netsnmp_assert(!"cache == valid"); /* always false */
+        tcp_load( NULL, NULL );	/* XXX - check for failure */
+    }
 #endif
 
 
@@ -278,10 +272,10 @@ tcp_handler(netsnmp_mib_handler          *handler,
         type = ASN_GAUGE;
         break;
     case TCPINSEGS:
-        ret_value = tcpstat.tcpInSegs & 0xffffffff;
+        ret_value = tcpstat.tcpInSegs;
         break;
     case TCPOUTSEGS:
-        ret_value = tcpstat.tcpOutSegs & 0xffffffff;
+        ret_value = tcpstat.tcpOutSegs;
         break;
     case TCPRETRANSSEGS:
         ret_value = tcpstat.tcpRetransSegs;
@@ -372,21 +366,21 @@ tcp_handler(netsnmp_mib_handler          *handler,
         type = ASN_GAUGE;
         break;
     case TCPINSEGS:
-        ret_value = tcpstat.tcps_rcvtotal & 0xffffffff;
+        ret_value = tcpstat.tcps_rcvtotal;
         break;
     case TCPOUTSEGS:
         /*
          * RFC 1213 defines this as the number of segments sent
          * "excluding those containing only retransmitted octets"
          */
-        ret_value = (tcpstat.tcps_sndtotal - tcpstat.tcps_sndrexmitpack) & 0xffffffff;
+        ret_value = tcpstat.tcps_sndtotal - tcpstat.tcps_sndrexmitpack;
         break;
     case TCPRETRANSSEGS:
         ret_value = tcpstat.tcps_sndrexmitpack;
         break;
     case TCPINERRS:
         ret_value = tcpstat.tcps_rcvbadsum + tcpstat.tcps_rcvbadoff
-#ifdef STRUCT_TCPSTAT_HAS_TCPS_RCVMEMDROP
+#ifdef HAVE_STRUCT_TCPSTAT_TCPS_RCVMEMDROP
             + tcpstat.tcps_rcvmemdrop
 #endif
             + tcpstat.tcps_rcvshort;
@@ -695,21 +689,6 @@ tcp_load(netsnmp_cache *cache, void *vmagic)
     }
     return ret_value;
 }
-#elif defined(NETBSD_STATS_VIA_SYSCTL)
-int
-tcp_load(netsnmp_cache *cache, void *vmagic)
-{
-    long ret_value = -1;
-
-    ret_value = netbsd_read_tcp_stat(&tcpstat);
-
-    if ( ret_value < 0 ) {
-       DEBUGMSGTL(("mibII/tcpScalar", "Failed to load TCP scalar Group (netbsd)\n"));
-    } else {
-        DEBUGMSGTL(("mibII/tcpScalar", "Loaded TCP scalar Group (netbsd)\n"));
-    }
-    return ret_value;
-}
 #elif defined (WIN32) || defined (cygwin)
 int
 tcp_load(netsnmp_cache *cache, void *vmagic)
