@@ -13,7 +13,7 @@ FindVarMethod var_extensible_vmstat;
 void
 init_vmstat(void)
 {
-    static oid  vmstat_oid[] = { NETSNMP_UCDAVIS_MIB, 11 };
+    const oid  vmstat_oid[] = { NETSNMP_UCDAVIS_MIB, 11 };
 
     DEBUGMSGTL(("vmstat", "Initializing\n"));
     netsnmp_register_scalar_group(
@@ -73,11 +73,11 @@ vmstat_handler(netsnmp_mib_handler          *handler,
          */
         case CPURAWUSER:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->user_ticks & 0xffffffff);
+                                        info->user_ticks );
              break;
         case CPURAWNICE:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->nice_ticks & 0xffffffff);
+                                        info->nice_ticks );
              break;
         case CPURAWSYSTEM:
              /*
@@ -88,29 +88,29 @@ vmstat_handler(netsnmp_mib_handler          *handler,
               *   if it has a non-zero value.
               */
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                       (info->sys2_ticks ?
+                                        info->sys2_ticks ?
                                         info->sys2_ticks :
-                                        info->sys_ticks ) & 0xffffffff);
+                                        info->sys_ticks );
              break;
         case CPURAWIDLE:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->idle_ticks & 0xffffffff);
+                                        info->idle_ticks );
              break;
         case CPURAWWAIT:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->wait_ticks & 0xffffffff);
+                                        info->wait_ticks );
              break;
         case CPURAWKERNEL:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->kern_ticks & 0xffffffff);
+                                        info->kern_ticks );
              break;
         case CPURAWINTR:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->intrpt_ticks & 0xffffffff);
+                                        info->intrpt_ticks );
              break;
         case CPURAWSOFTIRQ:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->sirq_ticks & 0xffffffff);
+                                        info->sirq_ticks );
              break;
 
         /*
@@ -129,10 +129,7 @@ vmstat_handler(netsnmp_mib_handler          *handler,
         case CPUUSER:
              if ( info->history && info->history[0].total_hist ) {
                  value  = (info->user_ticks  - info->history[0].user_hist)*100;
-                 if ( info->total_ticks - info->history[0].total_hist)
-                     value /= (info->total_ticks - info->history[0].total_hist);
-                 else
-                     value = 0;    /* or skip this entry */
+                 value /= (info->total_ticks - info->history[0].total_hist);
                  snmp_set_var_typed_integer(requests->requestvb,
                                             ASN_INTEGER, value);
              }
@@ -141,10 +138,7 @@ vmstat_handler(netsnmp_mib_handler          *handler,
              if ( info->history && info->history[0].total_hist ) {
                      /* or sys2_ticks ??? */
                  value  = (info->sys_ticks  - info->history[0].sys_hist)*100;
-                 if ( info->total_ticks - info->history[0].total_hist)
-                     value /= (info->total_ticks - info->history[0].total_hist);
-                 else
-                     value = 0;    /* or skip this entry */
+                 value /= (info->total_ticks - info->history[0].total_hist);
                  snmp_set_var_typed_integer(requests->requestvb,
                                             ASN_INTEGER, value);
              }
@@ -152,10 +146,7 @@ vmstat_handler(netsnmp_mib_handler          *handler,
         case CPUIDLE:
              if ( info->history && info->history[0].total_hist ) {
                  value  = (info->idle_ticks  - info->history[0].idle_hist)*100;
-                 if ( info->total_ticks - info->history[0].total_hist)
-                     value /= (info->total_ticks - info->history[0].total_hist);
-                 else
-                     value = 0;    /* or skip this entry */
+                 value /= (info->total_ticks - info->history[0].total_hist);
                  snmp_set_var_typed_integer(requests->requestvb,
                                             ASN_INTEGER, value);
              }
@@ -167,11 +158,11 @@ vmstat_handler(netsnmp_mib_handler          *handler,
          */
         case SYSRAWINTERRUPTS:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->nInterrupts & 0xffffffff);
+                                        info->nInterrupts );
              break;
         case SYSRAWCONTEXT:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->nCtxSwitches & 0xffffffff);
+                                        info->nCtxSwitches );
              break;
         case SYSINTERRUPTS:
              if ( info->history && info->history[0].total_hist ) {
@@ -193,11 +184,11 @@ vmstat_handler(netsnmp_mib_handler          *handler,
          */
         case RAWSWAPIN:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->swapIn & 0xffffffff);
+                                        info->swapIn );
              break;
         case RAWSWAPOUT:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->swapOut & 0xffffffff);
+                                        info->swapOut );
              break;
         case SWAPIN:
              if ( info->history && info->history[0].total_hist ) {
@@ -221,11 +212,11 @@ vmstat_handler(netsnmp_mib_handler          *handler,
          */
         case IORAWSENT:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->pageOut & 0xffffffff);
+                                        info->pageOut );
              break;
         case IORAWRECEIVE:
              snmp_set_var_typed_integer(requests->requestvb, ASN_COUNTER,
-                                        info->pageIn & 0xffffffff);
+                                        info->pageIn );
              break;
         case IOSENT:
              if ( info->history && info->history[0].total_hist ) {
