@@ -103,7 +103,6 @@ static int      localdebug;
 static int      exitval = 0;
 static int      use_getbulk = 1;
 static int      max_getbulk = 10;
-static int      extra_columns = 0;
 
 void            usage(void);
 void            get_field_names(void);
@@ -353,8 +352,6 @@ main(int argc, char *argv[])
 
     if (total_entries == 0)
         printf("%s: No entries\n", table_name);
-    if (extra_columns)
-	printf("%s: WARNING: More columns on agent than in MIB\n", table_name);
 
     return 0;
 }
@@ -400,7 +397,7 @@ print_table(void)
             printf("\nSNMP table %s, part %d\n\n", table_name, part);
         first_field = last_field;
         dp = data;
-        if (show_index && !no_headers && !column_width && first_pass) {
+        if (show_index && !no_headers && !column_width) {
             width = index_width;
             printf(index_fmt, "index");
         } else
@@ -709,7 +706,7 @@ get_table_entries(netsnmp_session * ss)
                                                           NETSNMP_DS_LIB_OID_OUTPUT_FORMAT)) {
                                 case NETSNMP_OID_OUTPUT_MODULE:
 				case 0:
-                                    name_p = strchr(buf, ':');
+                                    name_p = strrchr(buf, ':');
                                     break;
                                 case NETSNMP_OID_OUTPUT_SUFFIX:
                                     name_p = buf;
@@ -868,15 +865,6 @@ getbulk_table_entries(netsnmp_session * ss)
                         printf("%s => taken\n",
                                buf ? (char *) buf : "[NIL]");
                     }
-                    for (col = 0; col < fields; col++)
-                        if (column[col].subid == vars->name[rootlen])
-                            break;
-		    if (col == fields) {
-			extra_columns = 1;
-			last_var = vars;
-			vars = vars->next_variable;
-			continue;
-		    }
                     if (netsnmp_ds_get_boolean(NETSNMP_DS_LIBRARY_ID, 
                                               NETSNMP_DS_LIB_EXTENDED_INDEX)) {
                         name_p = strchr(buf, '[');
@@ -902,14 +890,7 @@ getbulk_table_entries(netsnmp_session * ss)
 					              NETSNMP_DS_LIB_OID_OUTPUT_FORMAT));
 			    exit(1);
                         }
-                        name_p = strchr(name_p, '.');
-                        if ( name_p == NULL ) {
-                            /* The 'strchr' call above failed, i.e. the results
-                             * don't seem to include instance subidentifiers! */
-                            running = 0;
-                            break;
-                        }
-                        name_p++;  /* Move on to the instance identifier */
+                        name_p = strchr(name_p, '.') + 1;
                     }
                     for (row = 0; row < entries; row++)
                         if (strcmp(name_p, indices[row]) == 0)
@@ -957,6 +938,9 @@ getbulk_table_entries(netsnmp_session * ss)
                     for (cp = buf; *cp; cp++)
                         if (*cp == '\n')
                             *cp = ' ';
+                    for (col = 0; col < fields; col++)
+                        if (column[col].subid == vars->name[rootlen])
+                            break;
                     dp[col] = buf;
                     i = out_len;
                     buf = NULL;
