@@ -79,7 +79,6 @@ if [ "x$SNMP_TMPDIR" = "x" -a "x$SNMP_HEADERONLY" != "xyes" ]; then
     export SNMP_TMP_PERSISTENTDIR
     mkdir $SNMP_TMPDIR
     mkdir $SNMP_TMP_PERSISTENTDIR
-    chmod 0700 $SNMP_TMPDIR $SNMP_TMP_PERSISTENTDIR
 fi
 
 if [ "x$SNMP_SAVE_TMPDIR" = "x" ]; then
@@ -87,13 +86,11 @@ if [ "x$SNMP_SAVE_TMPDIR" = "x" ]; then
     export SNMP_SAVE_TMPDIR
 fi
 
-SNMP_IGNORE_WINDOWS_REGISTRY="true"
-export SNMP_IGNORE_WINDOWS_REGISTRY
-SNMP_ENV_SEPARATOR="`$SNMP_UPDIR/net-snmp-config --env-separator`"
 SNMP_PERLPROG="`$SNMP_UPDIR/net-snmp-config --perlprog`"
 SNMP_TESTDIR="$SNMP_BASEDIR/tests"
 SNMP_CONFIG_FILE="$SNMP_TMPDIR/snmpd.conf"
 SNMPTRAPD_CONFIG_FILE="$SNMP_TMPDIR/snmptrapd.conf"
+SNMPAPP_CONFIG_FILE="$SNMP_TMPDIR/snmp.conf"
 AGENTX_CONFIG_FILE="$SNMP_TMPDIR/agentx.conf"
 SNMP_SNMPTRAPD_LOG_FILE="$SNMP_TMPDIR/snmptrapd.log"
 SNMP_SNMPTRAPD_PID_FILE="$SNMP_TMPDIR/snmptrapd.pid"
@@ -101,7 +98,7 @@ SNMP_SNMPD_PID_FILE="$SNMP_TMPDIR/snmpd.pid"
 SNMP_SNMPD_LOG_FILE="$SNMP_TMPDIR/snmpd.log"
 SNMP_AGENTX_PID_FILE="$SNMP_TMPDIR/agentx.pid"
 SNMP_AGENTX_LOG_FILE="$SNMP_TMPDIR/agentx.log"
-SNMPCONFPATH="${SNMP_TMPDIR}${SNMP_ENV_SEPARATOR}${SNMP_TMP_PERSISTENTDIR}"
+SNMPCONFPATH=${SNMP_TMPDIR}:${SNMP_TMP_PERSISTENTDIR}
 export SNMPCONFPATH
 SNMP_PERSISTENT_DIR=$SNMP_TMP_PERSISTENTDIR
 export SNMP_PERSISTENT_DIR
@@ -122,12 +119,6 @@ elif test -x /usr/sbin/netstat ; then
 elif test -x /usr/etc/netstat ; then
     # e.g. IRIX
     NETSTAT=/usr/etc/netstat
-elif test -x /cygdrive/c/windows/system32/netstat ; then
-    # Cygwin
-    NETSTAT=/cygdrive/c/windows/system32/netstat
-elif test -x /c/Windows/System32/netstat ; then
-    # MinGW + MSYS
-    NETSTAT=/c/Windows/System32/netstat
 else
     NETSTAT=""
 fi
